@@ -1,13 +1,13 @@
 package Bencher::Scenario::PerinciCmdLine::Completion;
 
-our $DATE = '2016-01-22'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
-use App::GenPericmdCompleterScript qw(gen_perinci_cmdline_completer_script);
+use App::GenPericmdCompleterScript qw(gen_pericmd_completer_script);
 use Bencher::ScenarioUtil::Completion qw(make_completion_participant);
 use File::Temp qw(tempdir);
 use Perinci::CmdLine::Gen qw(gen_pericmd_script);
@@ -102,7 +102,7 @@ Bencher::Scenario::PerinciCmdLine::Completion - Benchmark completion response ti
 
 =head1 VERSION
 
-This document describes version 0.02 of Bencher::Scenario::PerinciCmdLine::Completion (from Perl distribution Bencher-Scenarios-PerinciCmdLine), released on 2016-01-22.
+This document describes version 0.03 of Bencher::Scenario::PerinciCmdLine::Completion (from Perl distribution Bencher-Scenarios-PerinciCmdLine), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -112,6 +112,10 @@ To run benchmark with default option:
 
 For more options (dump scenario, list/include/exclude/add participants, list/include/exclude/add datasets, etc), see L<bencher> or run C<bencher --help>.
 
+=head1 DESCRIPTION
+
+Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+
 =head1 BENCHMARK PARTICIPANTS
 
 =over
@@ -120,26 +124,26 @@ For more options (dump scenario, list/include/exclude/add participants, list/inc
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
 Benchmark with default options (C<< bencher -m PerinciCmdLine::Completion >>):
 
- +----------------------------------------+-----------+-----------+---------+---------+
- | participant                            | rate (/s) | time (ms) | errors  | samples |
- +----------------------------------------+-----------+-----------+---------+---------+
- | oddeven-classic optval_number          | 9.4       | 1.1e+02   | 0.00057 | 20      |
- | oddeven-classic optname_common_version | 9.4       | 1.1e+02   | 0.00041 | 21      |
- | oddeven-classic optname_number         | 9.5       | 1.1e+02   | 0.00043 | 21      |
- | oddeven-classic optname_common_help    | 9.5       | 1.1e+02   | 0.00036 | 23      |
- | oddeven-lite optname_common_help       | 19        | 53        | 0.00028 | 20      |
- | oddeven-lite optname_common_version    | 19        | 53        | 0.0003  | 20      |
- | oddeven-lite optval_number             | 19        | 52        | 0.00016 | 20      |
- | oddeven-lite optname_number            | 19        | 52        | 0.0002  | 20      |
- +----------------------------------------+-----------+-----------+---------+---------+
+ #table1#
+ +----------------------------------------+-----------+-----------+------------+---------+---------+
+ | participant                            | rate (/s) | time (ms) | vs_slowest |  errors | samples |
+ +----------------------------------------+-----------+-----------+------------+---------+---------+
+ | oddeven-classic optval_number          |       9.7 |       100 |        1   | 0.00013 |      20 |
+ | oddeven-classic optname_common_help    |       9.8 |       100 |        1   | 0.00026 |      20 |
+ | oddeven-classic optname_common_version |       9.8 |       100 |        1   | 0.00023 |      20 |
+ | oddeven-classic optname_number         |       9.8 |       100 |        1   | 0.00017 |      23 |
+ | oddeven-lite optname_common_version    |      17   |        57 |        1.8 | 0.00022 |      21 |
+ | oddeven-lite optname_common_help       |      17   |        57 |        1.8 | 0.00013 |      20 |
+ | oddeven-lite optval_number             |      18   |        57 |        1.8 | 0.00014 |      20 |
+ | oddeven-lite optname_number            |      18   |        57 |        1.8 | 0.00013 |      20 |
+ +----------------------------------------+-----------+-----------+------------+---------+---------+
 
-=head1 DESCRIPTION
 
-Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
 
 =head1 HOMEPAGE
 
@@ -163,7 +167,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
