@@ -1,13 +1,13 @@
 package Bencher::Scenario::PerinciCmdLine::Runtime;
 
-our $DATE = '2016-01-22'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
-use App::GenPericmdCompleterScript qw(gen_perinci_cmdline_completer_script);
+use App::GenPericmdCompleterScript qw(gen_pericmd_completer_script);
 use File::Temp qw(tempdir);
 use Perinci::CmdLine::Gen qw(gen_pericmd_script);
 
@@ -118,7 +118,7 @@ Bencher::Scenario::PerinciCmdLine::Runtime - Benchmark completion response time,
 
 =head1 VERSION
 
-This document describes version 0.02 of Bencher::Scenario::PerinciCmdLine::Runtime (from Perl distribution Bencher-Scenarios-PerinciCmdLine), released on 2016-01-22.
+This document describes version 0.03 of Bencher::Scenario::PerinciCmdLine::Runtime (from Perl distribution Bencher-Scenarios-PerinciCmdLine), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -128,6 +128,10 @@ To run benchmark with default option:
 
 For more options (dump scenario, list/include/exclude/add participants, list/include/exclude/add datasets, etc), see L<bencher> or run C<bencher --help>.
 
+=head1 DESCRIPTION
+
+Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+
 =head1 BENCHMARK PARTICIPANTS
 
 =over
@@ -136,27 +140,27 @@ For more options (dump scenario, list/include/exclude/add participants, list/inc
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
 Benchmark with default options (C<< bencher -m PerinciCmdLine::Runtime >>):
 
- +-----------------------+-----------+-----------+---------+---------+
- | participant           | rate (/s) | time (ms) | errors  | samples |
- +-----------------------+-----------+-----------+---------+---------+
- | hello-classic         | 3.9       | 2.6e+02   | 0.001   | 20      |
- | hello-classic help    | 4         | 2.5e+02   | 0.00058 | 20      |
- | hello-classic version | 5.4       | 1.9e+02   | 0.00053 | 20      |
- | hello-lite            | 20        | 50        | 0.00015 | 20      |
- | hello-lite help       | 22        | 46        | 8.9e-05 | 20      |
- | hello-lite version    | 28        | 36        | 0.0001  | 20      |
- | hello-inline          | 72        | 14        | 3.8e-05 | 20      |
- | hello-inline version  | 95        | 11        | 2.5e-05 | 20      |
- | hello-inline help     | 97        | 10        | 2.8e-05 | 20      |
- +-----------------------+-----------+-----------+---------+---------+
+ #table1#
+ +-----------------------+-----------+-----------+------------+-----------+---------+
+ | participant           | rate (/s) | time (ms) | vs_slowest |  errors   | samples |
+ +-----------------------+-----------+-----------+------------+-----------+---------+
+ | hello-classic help    |      4.3  |       230 |       1    |   0.0006  |      20 |
+ | hello-classic         |      4.31 |       232 |       1.01 |   0.00016 |      20 |
+ | hello-classic version |      5.8  |       170 |       1.4  |   0.00029 |      20 |
+ | hello-lite            |     18    |        55 |       4.2  |   0.00012 |      20 |
+ | hello-lite help       |     20    |        51 |       4.6  |   0.00013 |      21 |
+ | hello-lite version    |     23    |        43 |       5.5  |   0.00015 |      20 |
+ | hello-inline          |     41    |        24 |       9.6  | 7.3e-05   |      20 |
+ | hello-inline version  |     81    |        12 |      19    | 5.4e-05   |      20 |
+ | hello-inline help     |     84    |        12 |      20    | 6.6e-05   |      20 |
+ +-----------------------+-----------+-----------+------------+-----------+---------+
 
-=head1 DESCRIPTION
 
-Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
 
 =head1 HOMEPAGE
 
@@ -180,7 +184,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
